<?php
/**
 * Translator Revolution WP Plugin
 * http://goo.gl/4E7Mx
 *
 * LICENSE
 *
 * You need to buy a license if you want use this script.
 * http://codecanyon.net/legal/market
 *
 * @package    Translator Revolution WP Plugin
 * @copyright  Copyright (c) 2015, SurStudio, www.surstudio.net
 * @license    http://codecanyon.net/licenses/standard
 * @version    1.8
 * @date       2015-02-02
 */
 
class SurStudioPluginTranslatorRevolutionLiteConfig {
	
	const NAME = 'TranslatorRevolutionLite';
	const VERSION = '1.8';
	const UI_NAME = 'Translator Revolution';
	const WIDGET_NAME = 'Translator Revolution';
	const WIDGET_INTERNAL_NAME = 'surstudio-translator-revolution';
	const ADMIN_LANGUAGE_DOMAIN = 'translator_revolution';
	const ADMIN_SETTINGS_NAME = 'translator-revolution-plugin-settings';
	const ADMIN_SETTINGS_IMPORT_EXPORT_NAME = 'translator-revolution-lite-plugin-import-export-settings';
	const DB_SETTINGS_NAME = 'translator-revolution-lite-settings';
	const DB_CACHE_WRITABLE_FLAG_NAME = 'translator-revolution-lite-cache-validate';
	const ENABLE_SUPPORT_TAB = true;

	protected static $_settings = null;

	public static function getName($_to_lower=false, $_ui=false) {
		
		if ($_ui)
			return $_to_lower ? strtolower(self::UI_NAME) : self::UI_NAME;
		else
			return $_to_lower ? strtolower(self::NAME) : self::NAME;
		
	}

	public static function getWidgetName($_internal=false) {
	
		return $_internal ? self::WIDGET_INTERNAL_NAME : self::WIDGET_NAME;
		
	}

	public static function getVersion() {
	
		return self::VERSION;
		
	}	

	public static function getAdminLanguageDomain() {
		
		return self::ADMIN_LANGUAGE_DOMAIN;
		
	}

	public static function getAdminPageTitle() {
		
		return SurStudioPluginTranslatorRevolutionLiteMessage::get('Plugin Settings', self::getName());
		
	}

	public static function getAdminHandle() {
		
		return self::ADMIN_SETTINGS_NAME;
		
	}

	public static function getAdminImportExportHandle() {
		
		return self::ADMIN_SETTINGS_IMPORT_EXPORT_NAME;
		
	}

	public static function isSupportTabEnabled() {
		
		return self::ENABLE_SUPPORT_TAB;
		
	}
	
	public static function getDbCacheWritableName() {
		
		return self::DB_CACHE_WRITABLE_FLAG_NAME;
		
	}
	
	public static function getDbSettingsName() {
		
		return self::DB_SETTINGS_NAME;
		
	}

	public static function setCacheFlag($_value) {
		
		$name = SurStudioPluginTranslatorRevolutionLiteConfig::getDbCacheWritableName();
		
		$value = $_value ? 'true' : 'false';
		
		if (!get_option($name))
			add_option($name, $value);
		else
			update_option($name, $value);
		
	}
	
	public static function getCacheFlag() {

		$option = get_option(SurStudioPluginTranslatorRevolutionLiteConfig::getDbCacheWritableName());
		
		if (!$option)
			return false;
			
		return $option == 'true';
		
	}
	
	protected static function _get_settings() {
		
		$option = get_option(SurStudioPluginTranslatorRevolutionLiteConfig::getDbSettingsName());
		return !$option ? array() : $option;
		
	}
	
	public static function getSettings($_force=false) {
		
		if (is_array(self::$_settings) && $_force == false)
			return self::$_settings;
		
		$defaults = self::getDefaults();

		$current = self::_get_settings();

		$result = SurStudioPluginTranslatorRevolutionLiteCommon::mergeArrays($defaults, $current);

		$result = self::_adjust_languages($result, $current);
		
		return self::$_settings = $result;
		
	}

	protected static function _adjust_languages($_settings, $_current) {
		
		$result = $_settings;
		
		if (array_key_exists('languages', $_current))
			$result['languages']['value'] = $_current['languages']['value'];
		
		return $result;
		
	}
	
	public static function getSetting($_name, $_force=false) {
		
		$settings = self::getSettings($_force);
		
		return $settings[$_name];
		
	}

	protected static function _compare_settings($_id, $_setting_1, $_setting_2) {
		
		if (SurStudioPluginTranslatorRevolutionLiteCommon::endsWith($_id, '_template'))
			return SurStudioPluginTranslatorRevolutionLiteCommon::stripBreakLinesAndTabs($_setting_1['value']) == SurStudioPluginTranslatorRevolutionLiteCommon::stripBreakLinesAndTabs($_setting_2['value']);
		
		if ($_id == 'override')
			if ($_setting_1['value'] != $_setting_2['value'] && SurStudioPluginTranslatorRevolutionLiteValidator::isEmpty($_setting_1['value']))
				return true;
		
		if ($_id == 'languages')
			return $_setting_1['value'] === $_setting_2['value'];
			
		return $_setting_1['value'] == $_setting_2['value'];
		
	}
	
	protected static function _get_settings_values_for_export() {
		
		$settings = self::_get_settings();
		
		return count($settings) > 0 ? base64_encode(serialize($settings)) : SurStudioPluginTranslatorRevolutionLiteMessage::get('export_empty');
		
	}
	
	public static function getSettingsValues($_force=false, $_new=true) {
		
		$result = array();
		$settings = self::getSettings($_force);
				
		$defaults = self::getDefaults();
				
		foreach ($settings as $key => $setting)
			if ($_new == false || !self::_compare_settings($key, $setting, $defaults[$key]))
				$result[$key] = array(
					'value' => $setting['value'],
					'option_id' => array_key_exists('option_id', $setting) ? $setting['option_id'] : null
				);
			
		return $result;

	}
	
	public static function getSettingValue($_name, $_force=false) {
		
		$setting = self::getSetting($_name, $_force);
		$result = $setting['value'];
		
		if (SurStudioPluginTranslatorRevolutionLiteValidator::isBool($result))
			$result = $result == 'true' || $result === true;
		
		return $result;
		
	}

	public static function getDefaults() {
		
		$result = array(

			'api_key' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('api_key_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('api_key_description'),
				'id' => 'surstudio_api_key',
				'type' => 'text',
				'value' => '',
				'group' => 1
			),
			
			'translation_service' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translation_service_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translation_service_description'),
				'id' => 'surstudio_translation_service',
				'type' => 'select',
				'values' => array(
					'ss' => 'SurStudio',
					'gt' => 'Google'
				),
				'value' => 'ss',
				'group' => 1
			),

			'google_api_key' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('google_api_key_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('google_api_key_description'),
				'id' => 'surstudio_google_api_key',
				'type' => 'text',
				'value' => '',
				'dependence' => 'translation_service',
				'dependence_show_value' => 'gt',
				'group' => 1
			),
			
			'from' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('from_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('from_description'),
				'id' => 'surstudio_from',
				'option_id' => 'from',
				'type' => 'select',
				'values' => SurStudioPluginTranslatorRevolutionLiteCommon::getLanguages(),
				'value' => 'en',
				'group' => 1
			),
			
			'languages' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('languages_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('languages_description'),
				'title_order_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('languages_order_title'),
				'description_order_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('languages_order_description'),
				'id' => 'surstudio_languages',
				'option_id' => 'languages',
				'values' => SurStudioPluginTranslatorRevolutionLiteCommon::getLanguages(),
				'value' => array('en', 'es', 'fr', 'de', 'da', 'ja', 'it', 'pt'),
				'type' => 'language',
				'columns' => 4,
				'group' => 1
			),

			'native_languages' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('native_languages_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('native_languages_description'),
				'id' => 'prisna_native_languages',
				'type' => 'toggle',
				'value' => 'false',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('native_languages_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('native_languages_false')
				),
				'group' => 1
			),
			
			'ui_heading' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('ui_heading_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('ui_heading_description'),
				'value' => 'false',
				'id' => 'surstudio_ui_heading',
				'type' => 'heading',
				'group' => 1
			),

			'corners' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('corners_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('corners_description'),
				'id' => 'surstudio_corners',
				'option_id' => 'corners',
				'type' => 'toggle',
				'value' => 'false',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('corners_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('corners_false')
				),
				'dependence' => 'ui_heading',
				'dependence_show_value' => 'true',
				'group' => 1
			),

			'align_mode' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('align_mode_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('align_mode_description'),
				'id' => 'surstudio_align_mode',
				'option_id' => 'alignMode',
				'type' => 'radio',
				'value' => 'center',
				'values' => array(
					'left' => SurStudioPluginTranslatorRevolutionLiteMessage::get('align_mode_left'),
					'center' => SurStudioPluginTranslatorRevolutionLiteMessage::get('align_mode_center'),
					'right' => SurStudioPluginTranslatorRevolutionLiteMessage::get('align_mode_right')
				),
				'dependence' => 'ui_heading',
				'dependence_show_value' => 'true',
				'group' => 1
			),

			'cookie' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('cookie_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('cookie_description'),
				'id' => 'surstudio_cookie',
				'option_id' => 'cookie',
				'type' => 'toggle',
				'value' => 'true',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('cookie_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('cookie_false')
				),
				'dependence' => 'ui_heading',
				'dependence_show_value' => 'true',
				'group' => 1
			),
			
			'cookie_persistency' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('cookie_persistency_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('cookie_persistency_description'),
				'id' => 'surstudio_cookie_persistency',
				'option_id' => 'cookiePersistency',
				'type' => 'toggle',
				'value' => 'true',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('cookie_persistency_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('cookie_persistency_false')
				),
				'dependence' => array('ui_heading', 'cookie'),
				'dependence_show_value' => array('true', 'true'),
				'group' => 1
			),
			
			'flags' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('flags_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('flags_description'),
				'id' => 'surstudio_flags',
				'option_id' => 'flags',
				'type' => 'toggle',
				'value' => 'true',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('flags_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('flags_false')
				),
				'dependence' => 'ui_heading',
				'dependence_show_value' => 'true',
				'group' => 1
			),
			
			'names' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('names_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('names_description'),
				'id' => 'surstudio_names',
				'option_id' => 'names',
				'type' => 'toggle',
				'value' => 'true',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('names_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('names_false')
				),
				'dependence' => 'ui_heading',
				'dependence_show_value' => 'true',
				'group' => 1
			),
			
			'short_names' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('short_names_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('short_names_description'),
				'id' => 'surstudio_short_names',
				'option_id' => 'shortNames',
				'type' => 'toggle',
				'value' => 'false',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('short_names_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('short_names_false')
				),
				'dependence' => array('ui_heading', 'names'),
				'dependence_show_value' => array('true', 'true'),
				'group' => 1
			),

			'loading' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('loading_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('loading_description'),
				'id' => 'surstudio_loading',
				'option_id' => 'loading',
				'type' => 'toggle',
				'value' => 'true',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('loading_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('loading_false')
				),
				'dependence' => 'ui_heading',
				'dependence_show_value' => 'true',
				'group' => 1
			),

			'restore' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('restore_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('restore_description'),
				'id' => 'surstudio_restore',
				'option_id' => 'restore',
				'type' => 'toggle',
				'value' => 'true',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('restore_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('restore_false')
				),
				'dependence' => 'ui_heading',
				'dependence_show_value' => 'true',
				'group' => 1
			),

			'complete' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('complete_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('complete_description'),
				'id' => 'surstudio_complete',
				'option_id' => 'complete',
				'type' => 'toggle',
				'value' => 'true',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('complete_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('complete_false')
				),
				'dependence' => 'ui_heading',
				'dependence_show_value' => 'true',
				'group' => 1
			),

			'auto_select' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('auto_select_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('auto_select_description'),
				'id' => 'surstudio_auto_select',
				'option_id' => 'autoSelect',
				'type' => 'toggle',
				'value' => 'true',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('auto_select_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('auto_select_false')
				),
				'dependence' => array('ui_heading', 'complete'),
				'dependence_show_value' => array('true', 'true'),
				'group' => 1
			),
			
			'selector_heading' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('selector_heading_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('selector_heading_description'),
				'value' => 'false',
				'id' => 'surstudio_selector_heading',
				'type' => 'heading',
				'group' => 1
			),

			'target_selector' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('target_selector_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('target_selector_description'),
				'id' => 'surstudio_target_selector',
				'option_id' => 'targetSelector',
				'type' => 'text',
				'value' => 'body',
				'dependence' => 'selector_heading',
				'dependence_show_value' => 'true',
				'group' => 1
			),
			
			'exclude_selector' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('exclude_selector_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('exclude_selector_description'),
				'id' => 'surstudio_exclude_selector',
				'option_id' => 'excludeSelector',
				'type' => 'text',
				'value' => 'code, #wpadminbar, input:hidden, .do-not-translate-me, .dont-translate',
				'dependence' => 'selector_heading',
				'dependence_show_value' => 'true',
				'group' => 1
			),
			
			'display_heading' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('display_heading_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('display_heading_description'),
				'value' => 'false',
				'id' => 'surstudio_display_heading',
				'type' => 'heading',
				'group' => 1
			),
			
			'exclude_pages' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('exclude_pages_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('exclude_pages_description'),
				'id' => 'surstudio_exclude_pages',
				'value' => array(''),
				'type' => 'expage',
				'dependence' => 'display_heading',
				'dependence_show_value' => 'true',
				'group' => 1
			),

			'exclude_posts' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('exclude_posts_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('exclude_posts_description'),
				'id' => 'surstudio_exclude_posts',
				'value' => array(''),
				'type' => 'expost',
				'dependence' => 'display_heading',
				'dependence_show_value' => 'true',
				'group' => 1
			),
			
			'exclude_categories' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('exclude_categories_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('exclude_categories_description'),
				'id' => 'surstudio_exclude_categories',
				'value' => array(''),
				'type' => 'excategory',
				'dependence' => 'display_heading',
				'dependence_show_value' => 'true',
				'group' => 1
			),

			'id' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('id_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('id_description'),
				'id' => 'surstudio_id',
				'option_id' => 'id',
				'type' => 'text',
				'value' => 'translator-jquery',
				'group' => 2
			),

			'test_mode' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('test_mode_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('test_mode_description'),
				'id' => 'surstudio_test_mode',
				'type' => 'toggle',
				'value' => 'false',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('test_mode_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('test_mode_false')
				),
				'group' => 2
			),

			'location_widget' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('location_widget_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('location_widget_description'),
				'id' => 'surstudio_location_widget',
				'option_id' => 'locationWidget',
				'type' => 'radio',
				'value' => 'top',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('location_widget_true', array(SurStudioPluginTranslatorRevolutionLiteCommon::getAdminWidgetsUrl())),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('location_widget_false'),
					'top' => SurStudioPluginTranslatorRevolutionLiteMessage::get('location_widget_top')
				),
				'group' => 2
			),

			'widget_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('widget_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('widget_class_description'),
				'id' => 'surstudio_widget_class',
				'type' => 'text',
				'value' => 'translator-bar-main-container',
				'dependence' => 'location_widget',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'bar_container_id' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('bar_container_id_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('bar_container_id_description'),
				'id' => 'surstudio_bar_container_id',
				'option_id' => 'barContainerId',
				'type' => 'text',
				'value' => 'translator-bar-jquery-container',
				'dependence' => 'location_widget',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'location_custom' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('location_custom_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('location_custom_description'),
				'id' => 'surstudio_location_custom',
				'option_id' => 'location',
				'type' => 'text',
				'value' => '',
				'dependence' => 'location_widget',
				'dependence_show_value' => 'false',
				'group' => 2
			),

			'custom_location_insert_mode' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('custom_location_insert_mode_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('custom_location_insert_mode_description'),
				'id' => 'surstudio_custom_location_insert_mode',
				'option_id' => 'customLocationAppendMode',
				'type' => 'select',
				'values' => array(
					'append' => 'Append',
					'prepend' => 'Prepend',
					'before' => 'Insert before',
					'after' => 'Insert after'
				),
				'value' => 'append',
				'dependence' => 'location_widget',
				'dependence_show_value' => 'false',
				'group' => 2
			),

			'custom_parent' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('custom_parent_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('custom_parent_description'),
				'id' => 'surstudio_custom_parent',
				'option_id' => 'customParent',
				'type' => 'select',
				'values' => array(
					'' => '',
					'div' => 'div',
					'span' => 'span',
					'li' => 'li',
					'ul-li' => 'ul > li',
					'ol-li' => 'ol > li',
					'td' => 'td',
					'tr-td' => 'tr > td',
					'table-tr-td' => 'table > tr > td'
				),
				'value' => '',
				'dependence' => array('location_widget', 'location_widget'),
				'dependence_show_value' => array('true', 'false'),
				'group' => 2
			),

			'custom_css' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('custom_css_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('custom_css_description'),
				'id' => 'surstudio_custom_css',
				'type' => 'textarea',
				'value' => '',
				'group' => 2
			),

			'cache_heading' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('cache_heading_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('cache_heading_description'),
				'value' => 'false',
				'id' => 'surstudio_cache_heading',
				'type' => 'heading',
				'group' => 2
			),

			'local_storage' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('local_storage_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('local_storage_description'),
				'id' => 'surstudio_local_storage',
				'option_id' => 'localStorage',
				'type' => 'toggle',
				'value' => 'false',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('local_storage_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('local_storage_false')
				),
				'dependence' => 'cache_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'local_storage_expires' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('local_storage_expires_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('local_storage_expires_description'),
				'min' => '1',
				'max' => '365',
				'step' => '1',
				'unit' => SurStudioPluginTranslatorRevolutionLiteMessage::get('unit_days'),
				'id' => 'surstudio_local_storage_expires',
				'option_id' => 'localStorageExpires',
				'value' => '30',
				'type' => 'range',
				'dependence' => array('cache_heading', 'local_storage'),
				'dependence_show_value' => array('true', 'true'),
				'group' => 2
			),
			
			'clear_local_storage' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('clear_local_storage_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('clear_local_storage_description'),
				'id' => 'surstudio_clear_local_storage',
				'option_id' => 'clearLocalStorage',
				'type' => 'toggle',
				'value' => 'false',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('clear_local_storage_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('clear_local_storage_false')
				),
				'dependence' => array('cache_heading', 'local_storage'),
				'dependence_show_value' => array('true', 'true'),
				'group' => 2
			),
			
			'style_classes_heading' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('style_classes_heading_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('style_classes_heading_description'),
				'value' => 'false',
				'id' => 'surstudio_style_classes_heading',
				'type' => 'heading',
				'group' => 2
			),

			'container_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('container_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('container_class_description'),
				'id' => 'surstudio_container_class',
				'option_id' => 'containerClass',
				'type' => 'text',
				'value' => 'translator-container',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'container_custom_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('container_custom_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('container_custom_class_description'),
				'id' => 'surstudio_container_custom_class',
				'option_id' => 'containerCustomClass',
				'type' => 'text',
				'value' => 'translator-container-custom',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'sub_container_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('sub_container_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('sub_container_class_description'),
				'id' => 'surstudio_sub_container_class',
				'option_id' => 'subContainerClass',
				'type' => 'text',
				'value' => 'translator-sub-container',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'loading_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('loading_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('loading_class_description'),
				'id' => 'surstudio_loading_class',
				'option_id' => 'loadingClass',
				'type' => 'text',
				'value' => 'translator-loading-left',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'completed_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('completed_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('completed_class_description'),
				'id' => 'surstudio_completed_class',
				'option_id' => 'completedClass',
				'type' => 'text',
				'value' => 'translator-completed-left',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'restore_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('restore_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('restore_class_description'),
				'id' => 'surstudio_restore_class',
				'option_id' => 'restoreClass',
				'type' => 'text',
				'value' => 'translator-restore',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'restore_container_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('restore_container_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('restore_container_class_description'),
				'id' => 'surstudio_restore_container_class',
				'option_id' => 'restoreContainerClass',
				'type' => 'text',
				'value' => 'translator-restore-container',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),	

			'align_left_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('align_left_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('align_left_class_description'),
				'id' => 'surstudio_align_left_class',
				'option_id' => 'alignLeftClass',
				'type' => 'text',
				'value' => 'translator-align-left',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'align_right_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('align_right_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('align_right_class_description'),
				'id' => 'surstudio_align_right_class',
				'option_id' => 'alignRightClass',
				'type' => 'text',
				'value' => 'translator-align-right',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'flags_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('flags_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('flags_class_description'),
				'id' => 'surstudio_flags_class',
				'option_id' => 'flagsClass',
				'type' => 'text',
				'value' => 'translator-flags',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'flags_and_names_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('flags_and_names_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('flags_and_names_class_description'),
				'id' => 'surstudio_flags_and_names_class',
				'option_id' => 'flagsAndNamesClass',
				'type' => 'text',
				'value' => 'translator-flags-and-names',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'flags_and_short_names_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('flags_and_short_names_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('flags_and_short_names_class_description'),
				'id' => 'surstudio_flags_and_short_names_class',
				'option_id' => 'flagsAndShortNamesClass',
				'type' => 'text',
				'value' => 'translator-flags-and-short-names',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'names_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('names_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('names_class_description'),
				'id' => 'surstudio_names_class',
				'option_id' => 'namesClass',
				'type' => 'text',
				'value' => 'translator-names',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),
			
			'short_names_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('short_names_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('short_names_class_description'),
				'id' => 'surstudio_short_names_class',
				'option_id' => 'shortNamesClass',
				'type' => 'text',
				'value' => 'translator-short-names',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'hidden_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('hidden_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('hidden_class_description'),
				'id' => 'surstudio_hidden_class',
				'option_id' => 'hiddenClass',
				'type' => 'text',
				'value' => 'translator-hidden',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'language_selector_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('language_selector_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('language_selector_class_description'),
				'id' => 'surstudio_language_selector_class',
				'option_id' => 'languageSelectorClass',
				'type' => 'text',
				'value' => 'translator-language-',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'corners_class' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('corners_class_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('corners_class_description'),
				'id' => 'surstudio_corners_class',
				'option_id' => 'cornersClass',
				'type' => 'text',
				'value' => 'translator-round-corners',
				'dependence' => 'style_classes_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'templates_heading' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('templates_heading_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('templates_heading_description'),
				'value' => 'false',
				'id' => 'surstudio_templates_heading',
				'type' => 'heading',
				'group' => 2
			),

			'flag_template' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('flag_template_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('flag_template_description'),
				'id' => 'surstudio_flag_template',
				'option_id' => 'flagTemplate',
				'type' => 'textarea',
				'value' => '<img src="{{ src }}" alt="{{ name }}" />',
				'dependence' => 'templates_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),
			
			'link_template' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('link_template_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('link_template_description'),
				'id' => 'surstudio_link_template',
				'option_id' => 'linkTemplate',
				'type' => 'textarea',
				'value' => '<td class="td-{{ language_selector_class }}">
	<a href="javascript:;" title="{{ name }}" class="{{ language_selector_class }}">{{ content }}</a>
</td>',
				'dependence' => 'templates_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'links_container_template' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('links_container_template_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('links_container_template_description'),
				'id' => 'surstudio_links_container_template',
				'option_id' => 'linksContainerTemplate',
				'type' => 'textarea',
				'value' => '<div class="{{ sub_container_class }}">
	<table border="0" cellspacing="0" cellpadding="0">
	<tbody>
		<tr>{{ content }}</tr>
	</tbody>
	</table>
</div>',
				'dependence' => 'templates_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'name_template' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('name_template_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('name_template_description'),
				'id' => 'surstudio_name_template',
				'option_id' => 'nameTemplate',
				'type' => 'textarea',
				'value' => '<span>{{ name }}</span>',
				'dependence' => 'templates_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),
			
			'restore_template' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('restore_template_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('restore_template_description'),
				'id' => 'surstudio_restore_template',
				'option_id' => 'restoreTemplate',
				'type' => 'textarea',
				'value' => '<div class="{{ hidden_class }} {{ restore_container_class }}">
	<a href="javascript:;" title="Restore" class="{{ restore_class }}">Restore</a>
</div>',
				'dependence' => 'templates_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'callbacks_heading' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('callbacks_heading_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('callbacks_heading_description'),
				'value' => 'false',
				'id' => 'surstudio_callbacks_heading',
				'type' => 'heading',
				'group' => 2
			),

			'on_before_initialize' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('on_before_initialize_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('on_before_initialize_description'),
				'id' => 'surstudio_on_before_initialize',
				'option_id' => 'onBeforeInitialize',
				'type' => 'textarea',
				'value' => 'function(translator, options) {}',
				'dependence' => 'callbacks_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'on_initialize' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('on_initialize_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('on_initialize_description'),
				'id' => 'surstudio_on_initialize',
				'option_id' => 'onInitialize',
				'type' => 'textarea',
				'value' => 'function(translator, options) {}',
				'dependence' => 'callbacks_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'on_start' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('on_start_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('on_start_description'),
				'id' => 'surstudio_on_start',
				'option_id' => 'onStart',
				'type' => 'textarea',
				'value' => 'function(filtered_elements, source, from, to, options) {}',
				'dependence' => 'callbacks_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'on_complete' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('on_complete_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('on_complete_description'),
				'id' => 'surstudio_on_complete',
				'option_id' => 'onComplete',
				'type' => 'textarea',
				'value' => 'function(filtered_elements, translation, source, from, to, options, restore) {}',
				'dependence' => 'callbacks_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),
			
			'other_customizations_heading' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('other_customizations_heading_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('other_customizations_heading_description'),
				'value' => 'false',
				'id' => 'surstudio_other_customizations_heading',
				'type' => 'heading',
				'group' => 2
			),

			'requests' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('requests_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('requests_description'),
				'min' => '1',
				'max' => '10',
				'step' => '1',
				'unit' => SurStudioPluginTranslatorRevolutionLiteMessage::get('unit_requests'),
				'id' => 'surstudio_requests',
				'option_id' => 'requests',
				'value' => '5',
				'type' => 'range',
				'dependence' => 'other_customizations_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),
			
			'jquery_auto_load' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('jquery_auto_load_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('jquery_auto_load_description'),
				'id' => 'surstudio_jquery_auto_load',
				'type' => 'toggle',
				'value' => 'true',
				'values' => array(
					'true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('jquery_auto_load_true'),
					'false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('jquery_auto_load_false')
				),
				'dependence' => 'other_customizations_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),
			
			'jquery_url' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('jquery_url_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('jquery_url_description'),
				'id' => 'surstudio_jquery_url',
				'type' => 'text',
				'value' => 'http://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js',
				'dependence' => array('other_customizations_heading', 'jquery_auto_load'),
				'dependence_show_value' => array('true', 'true'),
				'group' => 2
			),
			
			'separator' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('separator_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('separator_description'),
				'id' => 'surstudio_separator',
				'option_id' => 'separator',
				'type' => 'textarea',
				'value' => '',
				'dependence' => 'other_customizations_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),
			
			'custom_html' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('custom_html_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('custom_html_description'),
				'id' => 'surstudio_custom_html',
				'option_id' => 'customHtml',
				'value' => '',
				'type' => 'textarea',
				'dependence' => 'other_customizations_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),
						
			'override' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('override_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('override_description'),
				'id' => 'surstudio_override',
				'option_id' => 'override',
				'value' => '{}',
				'type' => 'textarea',
				'dependence' => 'other_customizations_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'custom_languages_names' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('custom_languages_names_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('custom_languages_names_description'),
				'id' => 'prisna_custom_languages_names',
				'option_id' => 'customLanguagesNames',
				'value' => '{}',
				'type' => 'textarea',
				'dependence' => 'other_customizations_heading',
				'dependence_show_value' => 'true',
				'group' => 2
			),

			'import' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('import_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('import_description'),
				'id' => 'surstudio_import',
				'value' => '',
				'type' => 'textarea',
				'group' => 3
			),

			'export' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('export_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('export_description'),
				'id' => 'surstudio_export',
				'value' => self::_get_settings_values_for_export(),
				'type' => 'export',
				'group' => 3
			),

			'translations' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_description'),
				'id' => 'surstudio_translations',
				'type' => 'translations',
				'value' => '',
				'folder' => SURSTUDIO_PLUGIN_TRANSLATOR_REVOLUTION_LITE_CACHE,
				'group' => 4
			),

			'translations_import' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_description'),
				'button_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_button_message'),
				'upload_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_upload'),
				'upload_button_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_upload_button'),
				'from_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_from'),
				'to_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_to'),
				'resource_title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_resource_title'),
				'resource_description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_resource_description'),
				'resource_description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_resource_description'),
				'resource_all_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_resource_all'),
				'resource_global_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_resource_global'),
				'action_title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_action_title'),
				'action_description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_action_description'),
				'action_add_and_edit' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_action_add_and_edit'),
				'action_add' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_action_add'),
				'action_edit' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_action_edit'),
				'test_title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_test_title'),
				'test_description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_test_description'),
				'test_true' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_test_true'),
				'test_false' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_test_false'),
				'log_title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_log_message'),
				'validate_csv_empty_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_validate_csv_empty_message'),
				'validate_csv_invalid_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_validate_csv_invalid_message'),
				'validate_language_empty_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_validate_language_empty_message'),
				'validate_resource_invalid_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_resource_invalid_message'),
				'validate_action_invalid_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_action_invalid_message'),
				'validate_test_invalid_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_test_invalid_message'),
				'log_added_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_log_added_message'),
				'log_edited_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_log_edited_message'),
				'log_removed_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_log_removed_message'),
				'log_omitted_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_log_omitted_message'),
				'log_created_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_log_created_message'),
				'log_yes_created_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_log_created_yes_message'),
				'log_no_created_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_log_created_no_message'),
				'log_test_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_log_test_message'),
				'no_import_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_import_no_import_message'),
				'id' => 'surstudio_translations_import',
				'type' => 'transimport',
				'value' => '',
				'folder' => SURSTUDIO_PLUGIN_TRANSLATOR_REVOLUTION_LITE_CACHE,
				'group' => 6
			),

			'translations_export' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_export_title'),
				'description_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_export_description'),
				'button_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_export_button_message'),
				'global_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_export_global_message'),
				'empty_collection_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('translations_export_empty_collection_message'),
				'id' => 'surstudio_translations_export',
				'type' => 'transexport',
				'value' => '',
				'folder' => SURSTUDIO_PLUGIN_TRANSLATOR_REVOLUTION_LITE_CACHE,
				'group' => 7
			),

			'faq' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('faq_title'),
				'q_1_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('faq_q_1'),
				'a_1_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('faq_a_1'),
				'q_2_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('faq_q_2'),
				'a_2_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('faq_a_2'),
				'q_3_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('faq_q_3'),
				'a_3_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('faq_a_3'),
				'q_4_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('faq_q_4'),
				'a_4_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('faq_a_4'),
				'q_5_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('faq_q_5'),
				'a_5_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('faq_a_5'),
				'id' => 'surstudio_faq',
				'type' => 'faq',
				'value' => '',
				'group' => 5
			),
			
			'support' => array(
				'title_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('support_title'),
				'step_1_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('support_step_1'),
				'step_2_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('support_step_2'),
				'step_3_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('support_step_3', SURSTUDIO_PLUGIN_TRANSLATOR_REVOLUTION_LITE_IMAGES),
				'step_4_message' => SurStudioPluginTranslatorRevolutionLiteMessage::get('support_step_4'),
				'id' => 'surstudio_support',
				'type' => 'support',
				'value' => '',
				'group' => 5
			)

		);
		
		return $result;
		
	}

}

?>